@@ -2,6 +2,7 @@ import argparse
 
 from pdm.cli.actions import do_import
 from pdm.cli.commands.base import BaseCommand
+from pdm.cli.options import deprecated
 from pdm.formats import FORMATS
 from pdm.project import Project
 
@@ -20,7 +21,17 @@ class Command(BaseCommand):
             help="import packages into dev dependencies",
         )
         parser.add_argument(
-            "-s", "--section", help="Specify target section to import into"
+            "-s",
+            "--section",
+            dest="group",
+            help="(DEPRECATED) Alias of `-G/--group`",
+            type=deprecated(
+                "`-s/--section` is deprecated in favor of `-G/--groups` "
+                "and will be removed in the next minor release."
+            ),
+        )
+        parser.add_argument(
+            "-G", "--group", help="Specify the target dependency group to import into"
         )
         parser.add_argument(
             "-f",
@@ -29,7 +40,7 @@ class Command(BaseCommand):
             help="Specify the file format explicitly",
         )
         parser.add_argument("filename", help="The file name")
-        parser.set_defaults(project=self.project_class("."))
+        parser.set_defaults(search_parent=False)
 
     def handle(self, project: Project, options: argparse.Namespace) -> None:
         do_import(project, options.filename, options.format, options)
