@@ -5,11 +5,12 @@ import re
 import shlex
 import subprocess
 import sys
-from typing import Dict, List, Optional, Union
+from typing import Any, Mapping, MutableMapping, Optional, Sequence, Tuple, Union, cast
 
 from pdm import termui
 from pdm.cli.actions import PEP582_PATH
 from pdm.cli.commands.base import BaseCommand
+from pdm.cli.utils import check_project_file
 from pdm.exceptions import PdmUsageError
 from pdm.project import Project
 
@@ -37,20 +38,27 @@ class Command(BaseCommand):
     @staticmethod
     def _run_command(
         project: Project,
-        args: Union[List[str], str],
+        args: Union[Sequence[str], str],
+        chdir: bool = False,
         shell: bool = False,
-        env: Optional[Dict[str, str]] = None,
+        env: Optional[Mapping[str, str]] = None,
         env_file: Optional[str] = None,
     ) -> None:
         if "PYTHONPATH" in os.environ:
-            pythonpath = os.pathsep.join([PEP582_PATH, os.getenv("PYTHONPATH")])
+            pythonpath = os.pathsep.join([PEP582_PATH, os.getenv("PYTHONPATH", "")])
         else:
             pythonpath = PEP582_PATH
         project_env = project.environment
         this_path = project_env.get_paths()["scripts"]
-        python_root = os.path.dirname(project.python_executable)
+        python_root = os.path.dirname(project.python.executable)
         new_path = os.pathsep.join([python_root, this_path, os.getenv("PATH", "")])
-        os.environ.update({"PYTHONPATH": pythonpath, "PATH": new_path})
+        os.environ.update(
+            {
+                "PYTHONPATH": pythonpath,
+                "PATH": new_path,
+                "PDM_PROJECT_ROOT": str(project.root),
+            }
+        )
         if project_env.packages_path:
             os.environ.update({"PEP582_PACKAGES": str(project_env.packages_path)})
         if env_file:
@@ -65,8 +73,10 @@ class Command(BaseCommand):
         if env:
             os.environ.update(env)
         if shell:
+            assert isinstance(args, str)
             sys.exit(subprocess.call(os.path.expandvars(args), shell=True))
 
+        assert isinstance(args, Sequence)
         command, *args = args
         expanded_command = project_env.which(command)
         if not expanded_command:
@@ -80,18 +90,23 @@ class Command(BaseCommand):
         if os.name == "nt" or "CI" in os.environ:
             # In order to make sure pytest is playing well,
             # don't hand over the process under a testing environment.
-            sys.exit(subprocess.call(expanded_args))
+            cwd = project.root if chdir else None
+            sys.exit(subprocess.call(expanded_args, cwd=cwd))
         else:
+            if chdir:
+                os.chdir(project.root)
             os.execv(expanded_command, expanded_args)
 
-    def _normalize_script(self, script):
+    def _normalize_script(
+        self, script: Any
+    ) -> Tuple[str, Union[Sequence[str], str], MutableMapping[str, Any]]:
         if not getattr(script, "items", None):
             # Regard as the same as {cmd = ... }
             kind = "cmd"
             value = script
             options = {}
         else:
-            script = dict(script)  # to remove the effect of tomlkit's container type.
+            script = dict(script)  # to remove the effect of atoml's container type.
             for key in self.TYPES:
                 if key in script:
                     kind = key
@@ -102,7 +117,7 @@ class Command(BaseCommand):
                     f"Script type must be one of ({', '.join(self.TYPES)})"
                 )
             options = script.copy()
-        if not all(key in self.OPTIONS for key in options):
+        if any(key not in self.OPTIONS for key in options):
             raise PdmUsageError(
                 f"pdm scripts only accept options: ({', '.join(self.OPTIONS)})"
             )
@@ -112,8 +127,8 @@ class Command(BaseCommand):
         self,
         project: Project,
         script_name: str,
-        args: List[str],
-        global_env_options: Dict[str, Union[str, Dict[str, str]]],
+        args: Sequence[str],
+        global_env_options: Mapping[str, Union[str, Mapping[str, str]]],
     ) -> None:
         script = project.scripts[script_name]
         kind, value, options = self._normalize_script(script)
@@ -123,9 +138,11 @@ class Command(BaseCommand):
                 value = shlex.split(str(value))
             args = value + list(args)
         elif kind == "shell":
-            args = " ".join([value] + list(args))
+            assert isinstance(value, str)
+            args = " ".join([value] + list(args))  # type: ignore
             options["shell"] = True
         elif kind == "call":
+            assert isinstance(value, str)
             module, _, func = value.partition(":")
             if not module or not func:
                 raise PdmUsageError(
@@ -139,16 +156,19 @@ class Command(BaseCommand):
                 "-c",
                 f"import sys, {module} as {short_name};"
                 f"sys.exit({short_name}.{func})",
-            ] + args
+            ] + list(args)
         if "env" in global_env_options:
-            options["env"] = {**global_env_options["env"], **options.get("env", {})}
+            options["env"] = {
+                **cast(Mapping[str, str], global_env_options["env"]),
+                **options.get("env", {}),
+            }
         options["env_file"] = options.get(
             "env_file", global_env_options.get("env_file")
         )
         project.core.ui.echo(
             f"Running {kind} script: {termui.green(str(args))}", err=True
         )
-        return self._run_command(project, args, **options)
+        return self._run_command(project, args, chdir=True, **options)
 
     def _show_list(self, project: Project) -> None:
         if not project.scripts:
@@ -159,16 +179,24 @@ class Command(BaseCommand):
             if name == "_":
                 continue
             kind, value, options = self._normalize_script(script)
-            result.append((termui.green(name), kind, value, options.get("help", "")))
+            result.append(
+                (termui.green(name), kind, str(value), options.get("help", ""))
+            )
         project.core.ui.display_columns(result, columns)
 
     def handle(self, project: Project, options: argparse.Namespace) -> None:
+        check_project_file(project)
         if options.list:
             return self._show_list(project)
         global_env_options = project.scripts.get("_", {}) if project.scripts else {}
+        assert isinstance(global_env_options, dict)
+        if not options.command:
+            raise PdmUsageError("No command given")
         if project.scripts and options.command in project.scripts:
             self._run_script(project, options.command, options.args, global_env_options)
         else:
             self._run_command(
-                project, [options.command] + options.args, **global_env_options
+                project,
+                [options.command] + options.args,
+                **global_env_options,  # type: ignore
             )
