@@ -3,22 +3,28 @@ from __future__ import annotations
 import argparse
 import os
 from argparse import Action, _ArgumentGroup
-from collections import ChainMap
+from collections import ChainMap, OrderedDict
+from json import dumps
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Iterable, Mapping, MutableMapping, cast
+from typing import TYPE_CHECKING, Any, Callable, Iterable, Mapping, MutableMapping, cast
 
 import atoml
 from packaging.specifiers import SpecifierSet
-from pip._vendor.pkg_resources import Distribution
 from resolvelib.structs import DirectedGraph
 
 from pdm import termui
+from pdm._types import Distribution
 from pdm.exceptions import PdmUsageError, ProjectError
 from pdm.formats import FORMATS
 from pdm.formats.base import make_array, make_inline_table
-from pdm.models.environment import WorkingSet
-from pdm.models.requirements import Requirement, strip_extras
+from pdm.models.requirements import (
+    Requirement,
+    filter_requirements_with_extras,
+    parse_requirement,
+    strip_extras,
+)
 from pdm.models.specifiers import get_specifier
+from pdm.models.working_set import WorkingSet
 from pdm.project import Project
 
 if TYPE_CHECKING:
@@ -98,7 +104,7 @@ class Package:
     """An internal class for the convenience of dependency graph building."""
 
     def __init__(
-        self, name: str, version: str, requirements: dict[str, Requirement]
+        self, name: str, version: str | None, requirements: dict[str, Requirement]
     ) -> None:
         self.name = name
         self.version = version  # if version is None, the dist is not installed.
@@ -116,24 +122,27 @@ class Package:
         return self.name == value.name
 
 
-def build_dependency_graph(working_set: WorkingSet) -> DirectedGraph:
+def build_dependency_graph(
+    working_set: WorkingSet, marker_env: dict[str, str] | None = None
+) -> DirectedGraph:
     """Build a dependency graph from locked result."""
     graph: DirectedGraph[Package | None] = DirectedGraph()
     graph.add(None)  # sentinel parent of top nodes.
-    node_with_extras = set()
+    node_with_extras: set[str] = set()
 
-    def add_package(key: str, dist: Distribution) -> Package:
+    def add_package(key: str, dist: Distribution | None) -> Package:
         name, extras = strip_extras(key)
         extras = extras or ()
         reqs: dict[str, Requirement] = {}
         if dist:
             requirements = (
-                Requirement.from_pkg_requirement(r)
-                for r in dist.requires(extras)  # type: ignore
+                parse_requirement(r)
+                for r in filter_requirements_with_extras(dist.requires or [], extras)
             )
             for req in requirements:
-                reqs[req.identify()] = req
-            version = dist.version
+                if not req.marker or req.marker.evaluate(marker_env):
+                    reqs[req.identify()] = req
+            version: str | None = dist.version
         else:
             version = None
 
@@ -144,9 +153,7 @@ def build_dependency_graph(working_set: WorkingSet) -> DirectedGraph:
             graph.add(node)
 
             for k in reqs:
-                child = add_package(
-                    k, cast(Distribution, working_set.get(strip_extras(k)[0]))
-                )
+                child = add_package(k, working_set.get(strip_extras(k)[0]))
                 graph.connect(node, child)
 
         return node
@@ -171,12 +178,16 @@ NON_LAST_CHILD = "├── "
 NON_LAST_PREFIX = "│   "
 
 
+def specifier_from_requirement(requirement: Requirement) -> str:
+    return str(requirement.specifier or "Any")
+
+
 def format_package(
     graph: DirectedGraph,
     package: Package,
     required: str = "",
     prefix: str = "",
-    visited: set[str] | None = None,
+    visited: frozenset[str] = frozenset(),
 ) -> str:
     """Format one package.
 
@@ -186,8 +197,6 @@ def format_package(
     :param prefix: prefix text for children
     :param visited: the visited package collection
     """
-    if visited is None:
-        visited = set()
     result = []
     version = (
         termui.red("[ not installed ]")
@@ -204,18 +213,17 @@ def format_package(
     result.append(f"{termui.green(package.name, bold=True)} {version} {required}\n")
     if package.name in visited:
         return "".join(result)
-    visited.add(package.name)
     children = sorted(graph.iter_children(package), key=lambda p: p.name)
     for i, child in enumerate(children):
         is_last = i == len(children) - 1
         head = LAST_CHILD if is_last else NON_LAST_CHILD
         cur_prefix = LAST_PREFIX if is_last else NON_LAST_PREFIX
-        required = str(package.requirements[child.name].specifier or "Any")
+        required = specifier_from_requirement(package.requirements[child.name])
         result.append(
             prefix
             + head
             + format_package(
-                graph, child, required, prefix + cur_prefix, visited.copy()
+                graph, child, required, prefix + cur_prefix, visited | {package.name}
             )
         )
     return "".join(result)
@@ -227,11 +235,9 @@ def format_reverse_package(
     child: Package | None = None,
     requires: str = "",
     prefix: str = "",
-    visited: set[str] | None = None,
+    visited: frozenset[str] = frozenset(),
 ) -> str:
     """Format one package for output reverse dependency graph."""
-    if visited is None:
-        visited = set()
     version = (
         termui.red("[ not installed ]")
         if not package.version
@@ -252,7 +258,6 @@ def format_reverse_package(
     result = [f"{termui.green(package.name, bold=True)} {version} {requires}\n"]
     if package.name in visited:
         return "".join(result)
-    visited.add(package.name)
     parents: list[Package] = sorted(
         filter(None, graph.iter_parents(package)), key=lambda p: p.name
     )
@@ -260,54 +265,156 @@ def format_reverse_package(
         is_last = i == len(parents) - 1
         head = LAST_CHILD if is_last else NON_LAST_CHILD
         cur_prefix = LAST_PREFIX if is_last else NON_LAST_PREFIX
-        requires = str(parent.requirements[package.name].specifier or "Any")
+        requires = specifier_from_requirement(parent.requirements[package.name])
         result.append(
             prefix
             + head
             + format_reverse_package(
-                graph, parent, package, requires, prefix + cur_prefix, visited.copy()
+                graph,
+                parent,
+                package,
+                requires,
+                prefix + cur_prefix,
+                visited | {package.name},
             )
         )
     return "".join(result)
 
 
+def package_is_project(package: Package, project: Project) -> bool:
+    return (
+        not project.environment.is_global
+        and bool(project.meta.name)
+        and package.name == project.meta.project_name.lower()
+    )
+
+
 def _format_forward_dependency_graph(project: Project, graph: DirectedGraph) -> str:
     """Format dependency graph for output."""
     content = []
     all_dependencies = ChainMap(*project.all_dependencies.values())
-    for package in sorted(graph.iter_children(None), key=lambda p: p.name):
+    top_level_dependencies = sorted(graph.iter_children(None), key=lambda p: p.name)
+    for package in top_level_dependencies:
         if package.name in all_dependencies:
-            required = str(all_dependencies[package.name].specifier or "Any")
-        elif (
-            not project.environment.is_global
-            and project.meta.name
-            and package.name == project.meta.project_name.lower()
-        ):
+            required = specifier_from_requirement(all_dependencies[package.name])
+        elif package_is_project(package, project):
             required = "This project"
         else:
             required = ""
-        content.append(format_package(graph, package, required, "", set()))
+        content.append(format_package(graph, package, required, ""))
     return "".join(content).strip()
 
 
 def _format_reverse_dependency_graph(
-    project: Project, graph: DirectedGraph[Package]
+    project: Project, graph: DirectedGraph[Package | None]
 ) -> str:
     """Format reverse dependency graph for output."""
     leaf_nodes = sorted(
-        (node for node in graph if not list(graph.iter_children(node))),
+        (node for node in graph if not list(graph.iter_children(node)) and node),
         key=lambda p: p.name,
     )
     content = [
-        format_reverse_package(graph, node, prefix="", visited=set())
-        for node in leaf_nodes
+        format_reverse_package(graph, node, prefix="") for node in leaf_nodes if node
     ]
     return "".join(content).strip()
 
 
+def build_forward_dependency_json_subtree(
+    root: Package,
+    project: Project,
+    graph: DirectedGraph[Package | None],
+    required_by: Package = None,
+    visited: frozenset[str] = frozenset(),
+) -> dict:
+    if not package_is_project(root, project):
+        requirements = (
+            required_by.requirements
+            if required_by
+            else ChainMap(*project.all_dependencies.values())
+        )
+        if root.name in requirements:
+            required = specifier_from_requirement(requirements[root.name])
+        else:
+            required = "Not required"
+    else:
+        required = "This project"
+
+    children = graph.iter_children(root) if root.name not in visited else []
+
+    return OrderedDict(
+        package=root.name,
+        version=root.version,
+        required=required,
+        dependencies=sorted(
+            (
+                build_forward_dependency_json_subtree(
+                    p, project, graph, root, visited | {root.name}
+                )
+                for p in children
+                if p
+            ),
+            key=lambda d: d["package"],
+        ),
+    )
+
+
+def build_reverse_dependency_json_subtree(
+    root: Package,
+    project: Project,
+    graph: DirectedGraph[Package | None],
+    requires: Package = None,
+    visited: frozenset[str] = frozenset(),
+) -> dict:
+    parents = graph.iter_parents(root) if root.name not in visited else []
+    return OrderedDict(
+        package=root.name,
+        version=root.version,
+        requires=specifier_from_requirement(root.requirements[requires.name])
+        if requires
+        else None,
+        dependents=sorted(
+            (
+                build_reverse_dependency_json_subtree(
+                    p, project, graph, root, visited | {root.name}
+                )
+                for p in parents
+                if p
+            ),
+            key=lambda d: d["package"],
+        ),
+    )
+
+
+def build_dependency_json_tree(
+    project: Project, graph: DirectedGraph[Package | None], reverse: bool
+) -> list[dict]:
+    if reverse:
+        top_level_packages = filter(
+            lambda n: not list(graph.iter_children(n)), graph
+        )  # leaf nodes
+        build_dependency_json_subtree: Callable = build_reverse_dependency_json_subtree
+    else:
+        top_level_packages = graph.iter_children(None)  # root nodes
+        build_dependency_json_subtree = build_forward_dependency_json_subtree
+    return [
+        build_dependency_json_subtree(p, project, graph)
+        for p in sorted(top_level_packages, key=lambda p: p.name if p else "")
+        if p
+    ]
+
+
 def format_dependency_graph(
-    project: Project, graph: DirectedGraph[Package], reverse: bool = False
+    project: Project,
+    graph: DirectedGraph[Package | None],
+    reverse: bool = False,
+    json: bool = False,
 ) -> str:
+    if json:
+        return dumps(
+            build_dependency_json_tree(project, graph, reverse),
+            indent=2,
+        )
+
     if reverse:
         return _format_reverse_dependency_graph(project, graph)
     else:
@@ -430,41 +537,41 @@ def format_resolution_impossible(err: ResolutionImpossible) -> str:
     result.append(
         "Please make sure the package names are correct. If so, you can either "
         "loosen the version constraints of these dependencies, or "
-        "set a narrower `requires-python` range in the pyproject.tomli."
+        "set a narrower `requires-python` range in the pyproject.toml."
     )
     return "\n".join(result)
 
 
-def translate_sections(
-    project: Project, default: bool, dev: bool, sections: Iterable[str]
+def translate_groups(
+    project: Project, default: bool, dev: bool, groups: Iterable[str]
 ) -> list[str]:
-    """Translate default, dev and sections containing ":all" into a list of sections"""
+    """Translate default, dev and groups containing ":all" into a list of groups"""
     optional_groups = set(project.meta.optional_dependencies or [])
     dev_groups = set(project.tool_settings.get("dev-dependencies", []))
-    sections_set = set(sections)
+    groups_set = set(groups)
     if dev is None:
         dev = True
-    if sections_set & dev_groups:
+    if groups_set & dev_groups:
         if not dev:
             raise PdmUsageError(
-                "--prod is not allowed with dev sections and should be left"
+                "--prod is not allowed with dev groups and should be left"
             )
     elif dev:
-        sections_set.update(dev_groups)
-    if ":all" in sections:
-        sections_set.discard(":all")
-        sections_set.update(optional_groups)
+        groups_set.update(dev_groups)
+    if ":all" in groups:
+        groups_set.discard(":all")
+        groups_set.update(optional_groups)
     if default:
-        sections_set.add("default")
+        groups_set.add("default")
     # Sorts the result in ascending order instead of in random order
     # to make this function pure
-    invalid_sections = sections_set - set(project.iter_sections())
-    if invalid_sections:
+    invalid_groups = groups_set - set(project.iter_groups())
+    if invalid_groups:
         project.core.ui.echo(
-            f"Ignoring non-existing sections: {invalid_sections}", fg="yellow", err=True
+            f"Ignoring non-existing groups: {invalid_groups}", fg="yellow", err=True
         )
-        sections_set -= invalid_sections
-    return sorted(sections_set)
+        groups_set -= invalid_groups
+    return sorted(groups_set)
 
 
 def merge_dictionary(
@@ -480,3 +587,17 @@ def merge_dictionary(
             target[key].update(value)
         elif isinstance(value, list):
             target[key].extend(atoml.item(v) for v in value)
+
+
+def frozen_requirement_from_dist(dist: Distribution) -> str:
+    """Get the requirement line from a distribution"""
+    from pip._vendor.pkg_resources import distributions_from_metadata
+
+    from pdm.models.pip_shims import FrozenRequirement
+
+    dist_path = str(dist._path)  # type: ignore
+    try:
+        pkg_dist = next(distributions_from_metadata(dist_path))
+    except StopIteration:
+        raise TypeError(f"Not a valid distribution metadata: {dist_path}")
+    return str(FrozenRequirement.from_dist(pkg_dist))
