@@ -7,14 +7,14 @@ from concurrent.futures._base import Future
 from concurrent.futures.thread import ThreadPoolExecutor
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
-from pip._vendor.pkg_resources import Distribution
-
 from pdm import termui
+from pdm._types import Distribution
 from pdm.exceptions import InstallationError
-from pdm.installers.installers import Installer, is_dist_editable
+from pdm.installers.manager import InstallManager
 from pdm.models.candidates import Candidate
 from pdm.models.environment import Environment
 from pdm.models.requirements import strip_extras
+from pdm.utils import is_egg_link
 
 
 class DummyFuture:
@@ -74,6 +74,7 @@ class Synchronizer:
         retry_times: int = 1,
         install_self: bool = False,
         no_editable: bool = False,
+        use_install_cache: bool = False,
     ) -> None:
         self.environment = environment
         self.clean = clean
@@ -81,6 +82,7 @@ class Synchronizer:
         self.retry_times = retry_times
         self.no_editable = no_editable
         self.install_self = install_self
+        self.use_install_cache = use_install_cache
 
         self.parallel = environment.project.config["parallel_install"]
         locked_repository = environment.project.locked_repository
@@ -92,6 +94,7 @@ class Synchronizer:
             for candidate in candidates.values():
                 candidate.req.editable = None  # type: ignore
         self.candidates = candidates
+        self._manager: InstallManager | None = None
 
     def create_executor(
         self,
@@ -101,8 +104,16 @@ class Synchronizer:
         else:
             return DummyExecutor()
 
-    def get_installer(self) -> Installer:
-        return Installer(self.environment)
+    @property
+    def manager(self) -> InstallManager:
+        if not self._manager:
+            self._manager = self.get_manager()
+        return self._manager
+
+    def get_manager(self) -> InstallManager:
+        return self.environment.project.core.install_manager_class(
+            self.environment, use_install_cache=self.use_install_cache
+        )
 
     @property
     def self_key(self) -> Optional[str]:
@@ -124,7 +135,7 @@ class Synchronizer:
                 can = candidates.pop(key)
                 if (
                     can.req.editable
-                    or is_dist_editable(dist)
+                    or is_egg_link(dist)
                     or (dist.version != can.version)
                 ):
                     to_update.append(key)
@@ -132,13 +143,13 @@ class Synchronizer:
                 key not in self.all_candidate_keys
                 and key not in self.SEQUENTIAL_PACKAGES
             ):
-                # Remove package only if it is not required by any section
+                # Remove package only if it is not required by any group
                 # Packages for packaging will never be removed
                 to_remove.append(key)
         to_add = list(
             {
                 strip_extras(name)[0]
-                for name, can in candidates.items()
+                for name, _ in candidates.items()
                 if name != self.self_key and strip_extras(name)[0] not in working_set
             }
         )
@@ -151,10 +162,9 @@ class Synchronizer:
     def install_candidate(self, key: str) -> Candidate:
         """Install candidate"""
         can = self.candidates[key]
-        installer = self.get_installer()
         with self.ui.open_spinner(f"Installing {can.format()}...") as spinner:
             try:
-                installer.install(can)
+                self.manager.install(can)
             except Exception:
                 spinner.fail(f"Install {can.format()} failed")
                 raise
@@ -167,48 +177,48 @@ class Synchronizer:
         """Update candidate"""
         can = self.candidates[key]
         dist = self.working_set[strip_extras(key)[0]]
-        installer = self.get_installer()
+        dist_version = dist.version
         with self.ui.open_spinner(
             f"Updating {termui.green(key, bold=True)} {termui.yellow(dist.version)} "
             f"-> {termui.yellow(can.version)}..."
         ) as spinner:
             try:
-                installer.uninstall(dist)
-                installer.install(can)
+                self.manager.uninstall(dist)
+                self.manager.install(can)
             except Exception:
                 spinner.fail(
                     f"Update {termui.green(key, bold=True)} "
-                    f"{termui.yellow(dist.version)} -> "
+                    f"{termui.yellow(dist_version)} -> "
                     f"{termui.yellow(can.version)} failed"
                 )
                 raise
             else:
                 spinner.succeed(
                     f"Update {termui.green(key, bold=True)} "
-                    f"{termui.yellow(dist.version)} -> "
+                    f"{termui.yellow(dist_version)} -> "
                     f"{termui.yellow(can.version)} successful"
                 )
         return dist, can
 
     def remove_distribution(self, key: str) -> Distribution:
         """Remove distributions with given names."""
-        installer = self.get_installer()
         dist = self.working_set[key]
+        dist_version = dist.version
         with self.ui.open_spinner(
             f"Removing {termui.green(key, bold=True)} {termui.yellow(dist.version)}..."
         ) as spinner:
             try:
-                installer.uninstall(dist)
+                self.manager.uninstall(dist)
             except Exception:
                 spinner.fail(
                     f"Remove {termui.green(key, bold=True)} "
-                    f"{termui.yellow(dist.version)} failed"
+                    f"{termui.yellow(dist_version)} failed"
                 )
                 raise
             else:
                 spinner.succeed(
                     f"Remove {termui.green(key, bold=True)} "
-                    f"{termui.yellow(dist.version)} successful"
+                    f"{termui.yellow(dist_version)} successful"
                 )
         return dist
 
@@ -249,7 +259,7 @@ class Synchronizer:
             lines.append(termui.bold("Packages to remove:"))
             for dist in to_remove:
                 lines.append(
-                    f"  - {termui.green(dist.key, bold=True)} "
+                    f"  - {termui.green(dist.metadata['Name'], bold=True)} "
                     f"{termui.yellow(dist.version)}"
                 )
         if lines:
@@ -291,15 +301,15 @@ class Synchronizer:
         ) -> None:
             error = future.exception()
             if error:
+                exc_info = (type(error), error, error.__traceback__)
+                termui.logger.exception("Error occurs: ", exc_info=exc_info)
                 failed_jobs.append((kind, key))
                 errors.extend(
                     [f"{kind} {termui.green(key)} failed:\n"]
-                    + traceback.format_exception(
-                        type(error), error, error.__traceback__
-                    )
+                    + traceback.format_exception(*exc_info)
                 )
 
-        with self.ui.logging("install"), self.environment.activate():
+        with self.ui.logging("install"):
             with self.ui.indent("  "):
                 for job in sequential_jobs:
                     kind, key = job
