@@ -1,18 +1,14 @@
 from __future__ import annotations
 
-import collections
 import os
 import shlex
 import shutil
 import subprocess
 import sys
-import sysconfig
 import tempfile
 from contextlib import contextmanager
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Generator, Iterator
-
-from pip._vendor import packaging, pkg_resources
+from typing import TYPE_CHECKING, Generator
 
 from pdm import termui
 from pdm.exceptions import BuildError
@@ -23,8 +19,8 @@ from pdm.models.in_process import (
     get_python_abi_tag,
     get_sys_config_paths,
 )
-from pdm.models.pip_shims import misc, patch_bin_prefix, req_uninstall
-from pdm.utils import cached_property, expand_env_vars_in_auth, get_finder, temp_environ
+from pdm.models.working_set import WorkingSet
+from pdm.utils import cached_property, get_finder, pdm_scheme
 
 if TYPE_CHECKING:
     from pdm._types import Source
@@ -45,40 +41,6 @@ def _get_shebang_path(executable: str, is_launcher: bool) -> bytes:
     return shlex.quote(executable).encode("utf-8")
 
 
-class WorkingSet(collections.abc.Mapping):
-    """A dict-like class that holds all installed packages in the lib directory."""
-
-    def __init__(
-        self,
-        paths: list[str] | None = None,
-        python: str = pkg_resources.PY_MAJOR,
-    ):
-        self.env = pkg_resources.Environment(paths, python=python)
-        self.pkg_ws = pkg_resources.WorkingSet(paths)
-        self.__add_editable_dists()
-
-    def __getitem__(self, key: str) -> pkg_resources.Distribution:
-        rv = self.env[key]
-        if rv:
-            return rv[0]
-        else:
-            raise KeyError(key)
-
-    def __len__(self) -> int:
-        return len(self.env._distmap)
-
-    def __iter__(self) -> Iterator[str]:
-        return iter(self.env)
-
-    def __add_editable_dists(self) -> None:
-        """Editable distributions are not present in pkg_resources.WorkingSet,
-        Get them from self.env
-        """
-        missing_keys = [key for key in self if key not in self.pkg_ws.by_key]
-        for key in missing_keys:
-            self.pkg_ws.add(self[key])
-
-
 class Environment:
     """Environment dependent stuff related to the selected Python interpreter."""
 
@@ -98,57 +60,7 @@ class Environment:
 
     def get_paths(self) -> dict[str, str]:
         """Get paths like ``sysconfig.get_paths()`` for installation."""
-        paths = sysconfig.get_paths()
-        scripts = "Scripts" if os.name == "nt" else "bin"
-        packages_path = self.packages_path
-        paths["platlib"] = paths["purelib"] = (packages_path / "lib").as_posix()
-        paths["scripts"] = (packages_path / scripts).as_posix()
-        paths["data"] = paths["prefix"] = packages_path.as_posix()
-        paths["include"] = paths["platinclude"] = paths["headers"] = (
-            packages_path / "include"
-        ).as_posix()
-        return paths
-
-    @contextmanager
-    def activate(self) -> Iterator:
-        """Activate the environment. Manipulate the ``PYTHONPATH`` and patches ``pip``
-        to be aware of local packages. This method acts like a context manager.
-
-        :param site_packages: whether to inject base site-packages into the sub env.
-        """
-        paths = self.get_paths()
-        with temp_environ():
-            working_set = self.get_working_set()
-            _old_ws = pkg_resources.working_set
-            pkg_resources.working_set = working_set.pkg_ws  # type: ignore
-            # HACK: Replace the is_local with environment version so that packages can
-            # be removed correctly.
-            _old_sitepackages = misc.site_packages
-            misc.site_packages = paths["purelib"]
-            _is_local = misc.is_local
-            misc.is_local = req_uninstall.is_local = self.is_local
-            _evaluate_marker = pkg_resources.evaluate_marker
-            pkg_resources.evaluate_marker = self.evaluate_marker
-            sys._original_executable = sys.executable  # type: ignore
-            sys.executable = self.interpreter.executable
-            with patch_bin_prefix(paths["scripts"]):
-                yield
-            sys.executable = sys._original_executable  # type: ignore
-            del sys._original_executable  # type: ignore
-            pkg_resources.evaluate_marker = _evaluate_marker
-            misc.is_local = req_uninstall.is_local = _is_local
-            misc.site_packages = _old_sitepackages
-            pkg_resources.working_set = _old_ws
-
-    def is_local(self, path: str) -> bool:
-        """PEP 582 version of ``is_local()`` function."""
-        return misc.normalize_path(path).startswith(
-            misc.normalize_path(self.packages_path.as_posix())
-        )
-
-    def evaluate_marker(self, text: str, extra: Any = None) -> bool:
-        marker = packaging.markers.Marker(text)
-        return marker.evaluate(self.marker_environment)
+        return pdm_scheme(str(self.packages_path))
 
     @cached_property
     def packages_path(self) -> Path:
@@ -183,10 +95,6 @@ class Environment:
         """
         if sources is None:
             sources = self.project.sources
-        sources = [
-            dict(source, url=expand_env_vars_in_auth(source["url"]))  # type: ignore
-            for source in sources
-        ]
 
         python_version = self.interpreter.version_tuple
         python_abi_tag = get_python_abi_tag(self.interpreter.executable)
@@ -205,13 +113,10 @@ class Environment:
     def get_working_set(self) -> WorkingSet:
         """Get the working set based on local packages directory."""
         paths = self.get_paths()
-        return WorkingSet(
-            [paths["platlib"], paths["purelib"]],
-            python=f"{self.interpreter.major}.{self.interpreter.minor}",
-        )
+        return WorkingSet([paths["platlib"], paths["purelib"]])
 
     @cached_property
-    def marker_environment(self) -> dict[str, Any]:
+    def marker_environment(self) -> dict[str, str]:
         """Get environment for marker evaluation"""
         return get_pep508_environment(self.interpreter.executable)
 
@@ -298,11 +203,6 @@ class GlobalEnvironment(Environment):
         paths["headers"] = paths["include"]
         return paths
 
-    def is_local(self, path: str) -> bool:
-        return misc.normalize_path(path).startswith(
-            misc.normalize_path(self.get_paths()["prefix"])
-        )
-
     @property
     def packages_path(self) -> Path | None:  # type: ignore
         return None
