@@ -125,6 +125,11 @@ class Config(MutableMapping[str, str]):
             env_var="PDM_USE_VENV",
             coerce=ensure_boolean,
         ),
+        "feature.install_cache": ConfigItem(
+            "Cache wheel installation and only put symlinks in the library root",
+            False,
+            coerce=ensure_boolean,
+        ),
     }
     del pypi_url, verify_ssl
 
