@@ -10,6 +10,7 @@ import re
 import shutil
 import subprocess
 import sys
+import sysconfig
 import tempfile
 import urllib.parse as parse
 from contextlib import contextmanager
@@ -29,10 +30,9 @@ from typing import (
 )
 
 from pip._vendor.packaging.tags import Tag
-from pip._vendor.pkg_resources import safe_name
 from pip._vendor.requests import Session
 
-from pdm._types import Source
+from pdm._types import Distribution, Source
 from pdm.models.pip_shims import (
     InstallCommand,
     InstallRequirement,
@@ -79,21 +79,20 @@ def prepare_pip_source_args(
         pip_args = []
     if sources:
         # Add the source to pip9.
-        pip_args.extend(["-i", sources[0]["url"]])  # type: ignore
+        pip_args.extend(["-i", sources[0]["url"]])
         # Trust the host if it's not verified.
         if not sources[0].get("verify_ssl", True):
             pip_args.extend(
                 ["--trusted-host", parse.urlparse(sources[0]["url"]).hostname or ""]
-            )  # type: ignore
+            )
         # Add additional sources as extra indexes.
-        if len(sources) > 1:
-            for source in sources[1:]:
-                pip_args.extend(["--extra-index-url", source["url"]])  # type: ignore
-                # Trust the host if it's not verified.
-                if not source.get("verify_ssl", True):
-                    pip_args.extend(
-                        ["--trusted-host", parse.urlparse(source["url"]).hostname or ""]
-                    )  # type: ignore
+        for source in sources[1:]:
+            pip_args.extend(["--extra-index-url", source["url"]])
+            # Trust the host if it's not verified.
+            if not source.get("verify_ssl", True):
+                pip_args.extend(
+                    ["--trusted-host", parse.urlparse(source["url"]).hostname or ""]
+                )
     return pip_args
 
 
@@ -478,4 +477,26 @@ def get_rev_from_url(url: str) -> str:
 
 
 def normalize_name(name: str) -> str:
-    return safe_name(name).lower()  # type: ignore
+    return re.sub(r"[^A-Za-z0-9.]+", "-", name).lower()
+
+
+def is_egg_link(dist: Distribution) -> bool:
+    return getattr(dist, "link_file", None) is not None
+
+
+def pdm_scheme(base: str) -> dict[str, str]:
+    """Return a PEP 582 style install scheme"""
+    if "pdm" not in sysconfig._INSTALL_SCHEMES:  # type: ignore
+        bin_prefix = "Scripts" if os.name == "nt" else "bin"
+        sysconfig._INSTALL_SCHEMES["pdm"] = {  # type: ignore
+            "stdlib": "{base}/lib",
+            "platstdlib": "{base}/lib",
+            "purelib": "{base}/lib",
+            "platlib": "{base}/lib",
+            "include": "{base}/include",
+            "scripts": "{base}/%s" % bin_prefix,
+            "data": "{base}",
+            "prefix": "{base}",
+            "headers": "{base}/include",
+        }
+    return sysconfig.get_paths("pdm", vars={"base": base}, expand=True)
