@@ -12,13 +12,13 @@ from tests import FIXTURES
 @pytest.mark.usefixtures("repository")
 def test_add_package(project, working_set, is_dev):
     actions.do_add(project, is_dev, packages=["requests"])
-    section = (
+    group = (
         project.tool_settings["dev-dependencies"]["dev"]
         if is_dev
         else project.meta["dependencies"]
     )
 
-    assert section[0] == "requests~=2.19"
+    assert group[0] == "requests~=2.19"
     locked_candidates = project.locked_repository.all_candidates
     assert locked_candidates["idna"].version == "2.7"
     for package in ("requests", "idna", "chardet", "urllib3", "certifi"):
@@ -26,8 +26,8 @@ def test_add_package(project, working_set, is_dev):
 
 
 @pytest.mark.usefixtures("repository")
-def test_add_package_to_custom_section(project, working_set):
-    actions.do_add(project, section="test", packages=["requests"])
+def test_add_package_to_custom_group(project, working_set):
+    actions.do_add(project, group="test", packages=["requests"])
 
     assert "requests" in project.meta.optional_dependencies["test"][0]
     locked_candidates = project.locked_repository.all_candidates
@@ -37,8 +37,8 @@ def test_add_package_to_custom_section(project, working_set):
 
 
 @pytest.mark.usefixtures("repository")
-def test_add_package_to_custom_dev_section(project, working_set):
-    actions.do_add(project, dev=True, section="test", packages=["requests"])
+def test_add_package_to_custom_dev_group(project, working_set):
+    actions.do_add(project, dev=True, group="test", packages=["requests"])
 
     dependencies = project.tool_settings["dev-dependencies"]["test"]
     assert "requests" in dependencies[0]
@@ -58,20 +58,33 @@ def test_add_editable_package(project, working_set, is_dev):
         is_dev,
         editables=["git+https://github.com/test-root/demo.git#egg=demo"],
     )
-    section = (
+    group = (
         project.tool_settings["dev-dependencies"]["dev"]
         if is_dev
         else project.meta["dependencies"]
     )
-    assert "demo" in section[0]
-    assert "-e git+https://github.com/test-root/demo.git#egg=demo" in section[1]
+    assert "demo" in group[0]
+    assert "-e git+https://github.com/test-root/demo.git#egg=demo" in group[1]
     locked_candidates = project.locked_repository.all_candidates
     assert locked_candidates["demo"].revision == "1234567890abcdef"
     assert locked_candidates["idna"].version == "2.7"
     assert "idna" in working_set
 
     actions.do_sync(project, no_editable=True)
-    assert not working_set["demo"].editable
+    assert not working_set["demo"].link_file
+
+
+@pytest.mark.usefixtures("repository", "vcs")
+def test_editable_package_override_non_editable(project, working_set):
+    project.environment.python_requires = PySpecSet(">=3.6")
+    actions.do_add(
+        project, packages=["git+https://github.com/test-root/demo.git#egg=demo"]
+    )
+    actions.do_add(
+        project,
+        editables=["git+https://github.com/test-root/demo.git#egg=demo"],
+    )
+    assert working_set["demo"].link_file
 
 
 @pytest.mark.usefixtures("repository", "working_set")
@@ -81,13 +94,13 @@ def test_add_remote_package_url(project, is_dev):
         is_dev,
         packages=["http://fixtures.test/artifacts/demo-0.0.1-py2.py3-none-any.whl"],
     )
-    section = (
+    group = (
         project.tool_settings["dev-dependencies"]["dev"]
         if is_dev
         else project.meta["dependencies"]
     )
     assert (
-        section[0]
+        group[0]
         == "demo @ http://fixtures.test/artifacts/demo-0.0.1-py2.py3-none-any.whl"
     )
 
@@ -223,11 +236,10 @@ def test_add_cached_vcs_requirement(project, mocker):
     if not cache_path.exists():
         cache_path.mkdir(parents=True)
     shutil.copy2(built_path, cache_path)
+    downloader = mocker.patch("pdm.models.pip_shims.unpack_url")
+    builder = mocker.patch("pdm.builders.WheelBuilder.build")
     actions.do_add(project, packages=[url], no_self=True)
     lockfile_entry = next(p for p in project.lockfile["package"] if p["name"] == "demo")
     assert lockfile_entry["revision"] == "1234567890abcdef"
-
-    downloader = mocker.patch("pdm.models.pip_shims.unpack_url")
-    builder = mocker.patch("pdm.builders.WheelBuilder.build")
     downloader.assert_not_called()
     builder.assert_not_called()
