@@ -236,3 +236,62 @@ def test_sdist_candidate_with_wheel_cache(project, mocker):
     candidate.build()
     builder.assert_not_called()
     assert Path(candidate.wheel) == Path(cache_path) / Path(built_path).name
+
+
+@pytest.mark.usefixtures("vcs")
+def test_cache_vcs_immutable_revision(project):
+    req = parse_requirement("git+https://github.com/test-root/demo.git@master#egg=demo")
+    candidate = Candidate(req, project.environment)
+    wheel = candidate.build()
+    with pytest.raises(ValueError):
+        Path(wheel).relative_to(project.cache_dir)
+    assert candidate.revision == "1234567890abcdef"
+
+    req = parse_requirement(
+        "git+https://github.com/test-root/demo.git@1234567890abcdef#egg=demo"
+    )
+    candidate = Candidate(req, project.environment)
+    wheel = candidate.build()
+    assert Path(wheel).relative_to(project.cache_dir)
+    assert candidate.revision == "1234567890abcdef"
+
+    # test the revision can be got correctly after cached
+    candidate = Candidate(req, project.environment)
+    wheel = candidate.prepare(True)
+    assert not candidate.source_dir
+    assert candidate.revision == "1234567890abcdef"
+
+
+def test_cache_egg_info_sdist(project):
+    req = parse_requirement("demo @ http://fixtures.test/artifacts/demo-0.0.1.tar.gz")
+    candidate = Candidate(req, project.environment)
+    wheel = candidate.build()
+    assert Path(wheel).relative_to(project.cache_dir)
+
+
+def test_invalidate_incompatible_wheel_link(project, index):
+    req = parse_requirement("demo")
+    candidate = Candidate(req, project.environment, name="demo", version="0.0.1")
+    candidate.prepare(True)
+    assert (
+        Path(candidate.wheel).name
+        == candidate.link.filename
+        == "demo-0.0.1-cp36-cp36m-win_amd64.whl"
+    )
+
+    candidate.prepare()
+    assert (
+        Path(candidate.wheel).name
+        == candidate.link.filename
+        == "demo-0.0.1-py2.py3-none-any.whl"
+    )
+
+
+def test_legacy_pep345_tag_link(project, index):
+    req = parse_requirement("pep345-legacy")
+    candidate = Candidate(req, project.environment)
+    try:
+        candidate.prepare()
+    except Exception:
+        pass
+    assert candidate.requires_python == ">=3,<4"
